RegApproxMatch

Struct RegApproxMatch 

pub struct RegApproxMatch<'a, T: ?Sized> { /* private fields */ }
This struct is returned by regaexec.

The match results from this function are very complex. See the TRE documentation for details on how this all works and corresponding fields, and what they mean.

This structure should never be instantiated outside the library.

Implementations

Source

impl<'a, T: ?Sized> RegApproxMatch<'a, T>

pub const fn cost(&self) -> i32

Gets the cost of the match

pub const fn num_ins(&self) -> i32

Gets the number of insertions if the match

pub const fn num_del(&self) -> i32

Gets the number of deletions if the match

pub const fn num_subst(&self) -> i32

Get the number of substitutions in the match

pub const fn get_orig_data(&self) -> &'a T

Gets an immutable reference to the underlying data

pub fn get_matches(&self) -> &[Option<&'a T>]

Gets the matches returned by this, as references to the data

pub fn into_matches(self) -> Vec<Option<&'a T>>

Consumes this result and returns its matches.