pub struct RegApproxMatch<'a, T: ?Sized> { /* private fields */ }Expand description
This struct is returned by regaexec.
The match results from this function are very complex. See the TRE documentation for details on how this all works and corresponding fields, and what they mean.
This structure should never be instantiated outside the library.
Implementations
Sourceimpl<'a, T: ?Sized> RegApproxMatch<'a, T>
impl<'a, T: ?Sized> RegApproxMatch<'a, T>
Sourcepub const fn get_orig_data(&self) -> &'a T
pub const fn get_orig_data(&self) -> &'a T
Gets an immutable reference to the underlying data
Sourcepub fn get_matches(&self) -> &[Option<&'a T>]
pub fn get_matches(&self) -> &[Option<&'a T>]
Gets the matches returned by this, as references to the data
Sourcepub fn into_matches(self) -> Vec<Option<&'a T>>
pub fn into_matches(self) -> Vec<Option<&'a T>>
Consumes this result and returns its matches.