docs.rs failed to build tre-regex-0.5.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
tre-regex-0.4.2
tre-regex
Safe API bindings to the TRE regex engine.
Documentation is available at docs.rs.
Requires Rust 1.85.1 or newer.
Features
wchar: enable wide-character regex support. Enabled by default.approx: enable approximate matching support. Enabled by default.vendored: use the vendored copy of TRE with tre-regex-sys; otherwise use the system TRE. Enabled by default.